package websocket

import (
	"encoding/json"
	"git.smsvc.net/pomodoro/GoTomato/internal/pomodoro"
	"git.smsvc.net/pomodoro/GoTomato/pkg/models"
	"github.com/gorilla/websocket"
	"log"
	"sync"
)

// Clients is a map of connected WebSocket clients, where each client is represented by the Client struct
var Clients = make(map[*websocket.Conn]*models.Client)
var mu sync.Mutex // Mutex to protect access to the Clients map

// handleClientCommands listens for commands from WebSocket clients and dispatches to the timer.
func handleClientCommands(ws *websocket.Conn) {
	// Create a new Client and add it to the Clients map
	mu.Lock()
	Clients[ws] = &models.Client{
		Conn: ws,
	}
	mu.Unlock()

	for {
		_, message, err := ws.ReadMessage()
		if err != nil {
			log.Printf("Client disconnected: %v", err)
			delete(Clients, ws)
			break
		}

		// Handle incoming commands
		var command models.ClientCommand
		err = json.Unmarshal(message, &command)
		if err != nil {
			log.Printf("Error unmarshalling command: %v", err)
			continue
		}

		// Process the command
		switch command.Command {
		case "start":
			if !pomodoro.IsPomodoroRunning() {
				go pomodoro.RunPomodoroTimer(Clients) // Start the timer with the list of clients
			}
		case "stop":
			if pomodoro.IsPomodoroRunning() {
				pomodoro.ResetPomodoro(Clients) // Reset Pomodoro
			}
		case "pause":
			if pomodoro.IsPomodoroRunning() && !pomodoro.IsPomodoroPaused() {
				pomodoro.PausePomodoro() // Pause the timer
			}
		case "resume":
			if pomodoro.IsPomodoroRunning() && pomodoro.IsPomodoroPaused() {
				pomodoro.ResumePomodoro() // Resume the timer
			}
		}

	}
}
